==> platform-client-v2-40.0.0-sources.jar: com/mypurecloud/sdk/v2/api/request/PostGdprRequestsRequest.java <==
package com.mypurecloud.sdk.v2.api.request;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonValue;
import com.mypurecloud.sdk.v2.ApiException;
import com.mypurecloud.sdk.v2.ApiClient;
import com.mypurecloud.sdk.v2.ApiRequest;
import com.mypurecloud.sdk.v2.ApiRequestBuilder;
import com.mypurecloud.sdk.v2.ApiResponse;
import com.mypurecloud.sdk.v2.Configuration;
import com.mypurecloud.sdk.v2.model.*;
import com.mypurecloud.sdk.v2.Pair;
import java.io.UnsupportedEncodingException;
import java.net.URLEncoder;
import java.util.Arrays;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.HashMap;
import java.util.Map;
import java.util.regex.Pattern;

import com.mypurecloud.sdk.v2.model.ErrorBody;
import com.mypurecloud.sdk.v2.model.GDPRRequest;
import com.mypurecloud.sdk.v2.model.GDPRRequestEntityListing;
import com.mypurecloud.sdk.v2.model.GDPRSubjectEntityListing;

public class PostGdprRequestsRequest {
    
	private GDPRRequest body;
	public GDPRRequest getBody() {
		return this.body;
	}

	public void setBody(GDPRRequest body) {
		this.body = body;
	}

	public PostGdprRequestsRequest withBody(GDPRRequest body) {
	    this.setBody(body);
	    return this;
	} 
	
	private Boolean deleteConfirmed;
	public Boolean getDeleteConfirmed() {
		return this.deleteConfirmed;
	}

	public void setDeleteConfirmed(Boolean deleteConfirmed) {
		this.deleteConfirmed = deleteConfirmed;
	}

	public PostGdprRequestsRequest withDeleteConfirmed(Boolean deleteConfirmed) {
	    this.setDeleteConfirmed(deleteConfirmed);
	    return this;
	} 
	
	private final Map<String, String> customHeaders = new HashMap<>();
    public Map<String, String> getCustomHeaders() {
        return this.customHeaders;
    }

    public void setCustomHeaders(Map<String, String> customHeaders) {
        this.customHeaders.clear();
        this.customHeaders.putAll(customHeaders);
    }

    public void addCustomHeader(String name, String value) {
        this.customHeaders.put(name, value);
    }

    public PostGdprRequestsRequest withCustomHeader(String name, String value) {
        this.addCustomHeader(name, value);
        return this;
    }

    public ApiRequest<GDPRRequest> withHttpInfo() {
        
        // verify the required parameter 'body' is set
        if (this.body == null) {
            throw new IllegalStateException("Missing the required parameter 'body' when building request for PostGdprRequestsRequest.");
        }
        

        return ApiRequestBuilder.create("POST", "/api/v2/gdpr/requests")
                .withQueryParameters("deleteConfirmed", "", deleteConfirmed)
        
                .withBody(body)
        
                .withCustomHeaders(customHeaders)
                .withContentTypes("application/json")
                .withAccepts("application/json")
                .withAuthNames("PureCloud Auth")
                .build();
    }

	public static Builder builder() {
		return new Builder();
	}

	
	public static Builder builder(GDPRRequest body) {
	    return new Builder()
	            .withRequiredParams(body);
	}
	

	public static class Builder {
		private final PostGdprRequestsRequest request;

		private Builder() {
			request = new PostGdprRequestsRequest();
		}

		
		public Builder withBody(GDPRRequest body) {
			request.setBody(body);
			return this;
		}
		
		public Builder withDeleteConfirmed(Boolean deleteConfirmed) {
			request.setDeleteConfirmed(deleteConfirmed);
			return this;
		}
		

		
		public Builder withRequiredParams(GDPRRequest body) {
			request.setBody(body);
			
			return this;
		}
		

		public PostGdprRequestsRequest build() {
            
            // verify the required parameter 'body' is set
            if (request.body == null) {
                throw new IllegalStateException("Missing the required parameter 'body' when building request for PostGdprRequestsRequest.");
            }
            
			return request;
		}
	}
}

==> platform-client-v2-176.0.0-sources.jar: com/mypurecloud/sdk/v2/api/request/PostGdprRequestsRequest.java <==
package com.mypurecloud.sdk.v2.api.request;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonValue;
import com.mypurecloud.sdk.v2.ApiException;
import com.mypurecloud.sdk.v2.ApiClient;
import com.mypurecloud.sdk.v2.ApiRequest;
import com.mypurecloud.sdk.v2.ApiRequestBuilder;
import com.mypurecloud.sdk.v2.ApiResponse;
import com.mypurecloud.sdk.v2.Configuration;
import com.mypurecloud.sdk.v2.model.*;
import com.mypurecloud.sdk.v2.Pair;
import java.io.UnsupportedEncodingException;
import java.net.URLEncoder;
import java.util.Arrays;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.HashMap;
import java.util.Map;
import java.util.regex.Pattern;

import com.mypurecloud.sdk.v2.model.ErrorBody;
import com.mypurecloud.sdk.v2.model.GDPRRequest;
import com.mypurecloud.sdk.v2.model.GDPRRequestEntityListing;
import com.mypurecloud.sdk.v2.model.GDPRSubjectEntityListing;

public class PostGdprRequestsRequest {

	private GDPRRequest body;
	public GDPRRequest getBody() {
		return this.body;
	}

	public void setBody(GDPRRequest body) {
		this.body = body;
	}

	public PostGdprRequestsRequest withBody(GDPRRequest body) {
	    this.setBody(body);
	    return this;
	} 

	private Boolean deleteConfirmed;
	public Boolean getDeleteConfirmed() {
		return this.deleteConfirmed;
	}

	public void setDeleteConfirmed(Boolean deleteConfirmed) {
		this.deleteConfirmed = deleteConfirmed;
	}

	public PostGdprRequestsRequest withDeleteConfirmed(Boolean deleteConfirmed) {
	    this.setDeleteConfirmed(deleteConfirmed);
	    return this;
	} 

	private final Map<String, String> customHeaders = new HashMap<>();
    public Map<String, String> getCustomHeaders() {
        return this.customHeaders;
    }

    public void setCustomHeaders(Map<String, String> customHeaders) {
        this.customHeaders.clear();
        this.customHeaders.putAll(customHeaders);
    }

    public void addCustomHeader(String name, String value) {
        this.customHeaders.put(name, value);
    }

    public PostGdprRequestsRequest withCustomHeader(String name, String value) {
        this.addCustomHeader(name, value);
        return this;
    }

    public ApiRequest<GDPRRequest> withHttpInfo() {
        
        // verify the required parameter 'body' is set
        if (this.body == null) {
            throw new IllegalStateException("Missing the required parameter 'body' when building request for PostGdprRequestsRequest.");
        }
        

        return ApiRequestBuilder.create("POST", "/api/v2/gdpr/requests")

                .withQueryParameters("deleteConfirmed", "", deleteConfirmed)
        
                .withBody(body)

		.withCustomHeaders(customHeaders)
                .withContentTypes("application/json")
                .withAccepts("application/json")
                .withAuthNames("PureCloud OAuth")
                .build();
    }

	public static Builder builder() {
		return new Builder();
	}


	public static Builder builder(GDPRRequest body) {
	    return new Builder()
	            .withRequiredParams(body);
	}


	public static class Builder {
		private final PostGdprRequestsRequest request;

		private Builder() {
			request = new PostGdprRequestsRequest();
		}


		public Builder withBody(GDPRRequest body) {
			request.setBody(body);
			return this;
		}

		public Builder withDeleteConfirmed(Boolean deleteConfirmed) {
			request.setDeleteConfirmed(deleteConfirmed);
			return this;
		}



		public Builder withRequiredParams(GDPRRequest body) {
			request.setBody(body);

			return this;
		}


		public PostGdprRequestsRequest build() {
            
            // verify the required parameter 'body' is set
            if (request.body == null) {
                throw new IllegalStateException("Missing the required parameter 'body' when building request for PostGdprRequestsRequest.");
            }
            
			return request;
		}
	}
}
